[dpdk-stable] patch 'net/sfc/base: add check for TUNNEL module in NIC reset API' has been queued to stable release 18.08.1

Kevin Traynor ktraynor at redhat.com
Wed Nov 21 17:03:59 CET 2018


Hi,

FYI, your patch has been queued to stable release 18.08.1

Note it hasn't been pushed to http://dpdk.org/browse/dpdk-stable yet.
It will be pushed if I get no objections before 11/26/18. So please
shout if anyone has objections.

Also note that after the patch there's a diff of the upstream commit vs the patch applied
to the branch. If the code is different (ie: not only metadata diffs), due for example to
a change in context or macro names, please double check it.

Thanks.

Kevin Traynor

---
>From e3cf8013ae94a41d6ec9b0b60032dd651472844a Mon Sep 17 00:00:00 2001
From: Vijay Srivastava <vijays at solarflare.com>
Date: Mon, 10 Sep 2018 10:33:11 +0100
Subject: [PATCH] net/sfc/base: add check for TUNNEL module in NIC reset API

[ upstream commit f933b46a0a95dd3a7fd5d206a24649d847fffbb6 ]

Fixes: 17551f6dffcc ("net/sfc/base: add API to control UDP tunnel ports")

Signed-off-by: Vijay Srivastava <vijays at solarflare.com>
Signed-off-by: Andrew Rybchenko <arybchenko at solarflare.com>
---
 drivers/net/sfc/base/efx_nic.c | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

-- 
2.19.0

---
  Diff of the applied patch vs upstream commit (please double-check if non-empty:
---
--- -	2018-11-21 15:59:13.850817242 +0000
+++ 0009-net-sfc-base-add-check-for-TUNNEL-module-in-NIC-rese.patch	2018-11-21 15:59:13.000000000 +0000
@@ -1,10 +1,11 @@
-From f933b46a0a95dd3a7fd5d206a24649d847fffbb6 Mon Sep 17 00:00:00 2001
+From e3cf8013ae94a41d6ec9b0b60032dd651472844a Mon Sep 17 00:00:00 2001
 From: Vijay Srivastava <vijays at solarflare.com>
 Date: Mon, 10 Sep 2018 10:33:11 +0100
 Subject: [PATCH] net/sfc/base: add check for TUNNEL module in NIC reset API
 
+[ upstream commit f933b46a0a95dd3a7fd5d206a24649d847fffbb6 ]
+
 Fixes: 17551f6dffcc ("net/sfc/base: add API to control UDP tunnel ports")
-Cc: stable at dpdk.org
 
 Signed-off-by: Vijay Srivastava <vijays at solarflare.com>
 Signed-off-by: Andrew Rybchenko <arybchenko at solarflare.com>


More information about the stable mailing list
diff --git a/drivers/net/sfc/base/efx_nic.c b/drivers/net/sfc/base/efx_nic.c
index 6314ae2ff..0e8ed9c2a 100644
--- a/drivers/net/sfc/base/efx_nic.c
+++ b/drivers/net/sfc/base/efx_nic.c
@@ -550,5 +550,5 @@ efx_nic_reset(
 	EFSYS_ASSERT(enp->en_mod_flags & EFX_MOD_PROBE);
 	/*
 	 * All modules except the MCDI, PROBE, NVRAM, VPD, MON
 	 * (which we do not reset here) must have been shut down or never
 	 * initialized.
@@ -561,4 +561,7 @@ efx_nic_reset(
 	mod_flags &= ~(EFX_MOD_MCDI | EFX_MOD_PROBE | EFX_MOD_NVRAM |
 	    EFX_MOD_VPD | EFX_MOD_MON);
+#if EFSYS_OPT_TUNNEL
+	mod_flags &= ~EFX_MOD_TUNNEL;
+#endif /* EFSYS_OPT_TUNNEL */
 	EFSYS_ASSERT3U(mod_flags, ==, 0);
 	if (mod_flags != 0) {
@@ -550,5 +550,5 @@ efx_nic_reset(
 	EFSYS_ASSERT(enp->en_mod_flags & EFX_MOD_PROBE);
 	/*
-	 * All modules except the MCDI, PROBE, NVRAM, VPD, MON
+	 * All modules except the MCDI, PROBE, NVRAM, VPD, MON, TUNNEL
 	 * (which we do not reset here) must have been shut down or never
 	 * initialized.